@@ -4,13 +4,9 @@ use crate::error::Error;
 use crate::subscription::Subscription;
 use crate::topic::Topic;
 use google_auth::TokenManager;
-use once_cell::sync::OnceCell;
 use tonic::transport::{Certificate, Channel, ClientTlsConfig};
 use tonic::{IntoRequest, Request};
 
-static DOMAIN_NAME: OnceCell<String> = OnceCell::new();
-static ENDPOINT: OnceCell<String> = OnceCell::new();
-
 #[derive(Clone)]
 pub struct Client {
     pub(crate) project_id: String,
@@ -20,28 +16,32 @@ pub struct Client {
 }
 
 impl Client {
+    pub(crate) const DOMAIN_NAME: &'static str = "pubsub.googleapis.com";
     pub(crate) const SCOPES: [&'static str; 2] = [
         "https://www.googleapis.com/auth/cloud-platform",
         "https://www.googleapis.com/auth/pubsub",
     ];
     pub async fn new(project_id: &str) -> Result<Self, Error> {
-        if let Ok(host) = std::env::var("PUBSUB_EMULATOR_HOST") {
-            let (domain, port) = host.split_once(":").unwrap();
-            DOMAIN_NAME.set(String::from(domain)).unwrap();
-            ENDPOINT.set(format!("http://{}:{}", host, port)).unwrap();
-        } else {
-            DOMAIN_NAME
-                .set(String::from("pubsub.googleapis.com"))
-                .unwrap();
-            ENDPOINT
-                .set(String::from("https://pubsub.googleapis.com"))
-                .unwrap();
-        }
         let pem = get_pem();
+        let uri = match std::env::var("PUBSUB_EMULATOR_HOST") {
+            Ok(host) => {
+                let (host, port) = host.split_once(":").unwrap();
+                tonic::transport::Uri::builder()
+                    .scheme("https")
+                    .authority(format!("{}:{}", host, port).as_str())
+                    .build()
+                    .unwrap()
+            }
+            Err(_) => tonic::transport::Uri::builder()
+                .scheme("https")
+                .authority(Self::DOMAIN_NAME)
+                .build()
+                .unwrap(),
+        };
         let tls_config = ClientTlsConfig::new()
             .ca_certificate(Certificate::from_pem(&pem))
-            .domain_name(DOMAIN_NAME.get().unwrap());
-        let channel = Channel::from_static(ENDPOINT.get().unwrap())
+            .domain_name(Self::DOMAIN_NAME);
+        let channel = Channel::builder(uri)
             .tls_config(tls_config)?
             .connect()
             .await?;
